===========================
Sample Masakari Policy File
===========================

The following is a sample masakari policy file for adaptation and use.

The sample policy can also be viewed in :download:`file form
</_static/masakari.policy.yaml.sample>`.

.. important::

   The sample policy file is auto-generated from masakari when this
   documentation is built.

.. literalinclude:: /_static/masakari.policy.yaml.sample
